/*
 * JBoss, Home of Professional Open Source
 * Copyright 2010, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */

package org.jboss.remoting3.metadata;

import java.util.ArrayList;
import java.util.List;
import org.jboss.xnio.metadata.OptionMetaData;

import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlElementWrapper;
import javax.xml.bind.annotation.XmlType;

@XmlType(name = "endpoint", propOrder = {})
public final class EndpointMetaData {
    private RefMetaData executor;
    private RefMetaData tcpConnector;
    private RefMetaData sslConnector;
    private List<OptionMetaData> options = new ArrayList<OptionMetaData>();
    private String name;
    private boolean defaultFlag = false;

    public RefMetaData getExecutor() {
        return executor;
    }

    @XmlElement(name = "executor")
    public void setExecutor(final RefMetaData executor) {
        this.executor = executor;
    }

    public List<OptionMetaData> getOptions() {
        return options;
    }

    public RefMetaData getTcpConnector() {
        return tcpConnector;
    }

    @XmlElement(name = "tcp-connector", required = true)
    public void setTcpConnector(final RefMetaData tcpConnector) {
        this.tcpConnector = tcpConnector;
    }

    public RefMetaData getSslConnector() {
        return sslConnector;
    }

    @XmlElement(name = "ssl-connector")
    public void setSslConnector(final RefMetaData sslConnector) {
        this.sslConnector = sslConnector;
    }

    @XmlElementWrapper(name = "options")
    @XmlElement(name = "option", type = OptionMetaData.class)
    public void setOptions(final List<OptionMetaData> options) {
        this.options = options;
    }

    public String getName() {
        return name;
    }

    @XmlAttribute(required = true)
    public void setName(final String name) {
        this.name = name;
    }

    public boolean isDefaultFlag() {
        return defaultFlag;
    }

    @XmlAttribute(name = "default")
    public void setDefaultFlag(final boolean defaultFlag) {
        this.defaultFlag = defaultFlag;
    }
}
