/*
 * JBoss, Home of Professional Open Source
 * Copyright 2008, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */

package org.jboss.remoting3.metadata;

import java.util.ArrayList;
import java.util.List;
import org.jboss.xnio.metadata.OptionMetaData;

import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlElementWrapper;
import javax.xml.bind.annotation.XmlType;
import javax.xml.bind.annotation.XmlAttribute;

/**
 *
 */
@XmlType(name = "service", propOrder = {})
public final class ServiceMetaData {

    private RefMetaData clientListener;
    private RefMetaData requestClassName;
    private RefMetaData replyClassName;
    private RefMetaData classloader;
    private List<OptionMetaData> options = new ArrayList<OptionMetaData>();
    private String type;
    private String groupName;

    public RefMetaData getClientListener() {
        return clientListener;
    }

    @XmlElement(name = "client-listener", required = true)
    public void setClientListener(final RefMetaData clientListener) {
        this.clientListener = clientListener;
    }

    public RefMetaData getRequestClassName() {
        return requestClassName;
    }

    @XmlElement(name = "request-class", required = true)
    public void setRequestClassName(final RefMetaData requestClassName) {
        this.requestClassName = requestClassName;
    }

    public RefMetaData getReplyClassName() {
        return replyClassName;
    }

    @XmlElement(name = "reply-class", required = true)
    public void setReplyClassName(final RefMetaData replyClassName) {
        this.replyClassName = replyClassName;
    }

    public RefMetaData getClassloader() {
        return classloader;
    }

    @XmlElement(name = "classloader")
    public void setClassloader(final RefMetaData classloader) {
        this.classloader = classloader;
    }

    public List<OptionMetaData> getOptions() {
        return options;
    }

    @XmlElementWrapper(name = "options")
    @XmlElement(name = "option", type = OptionMetaData.class)
    public void setOptions(final List<OptionMetaData> options) {
        this.options = options;
    }

    public String getType() {
        return type;
    }

    @XmlAttribute(name = "type", required = true)
    public void setType(final String type) {
        this.type = type;
    }

    public String getGroupName() {
        return groupName;
    }

    @XmlAttribute(name = "group-name")
    public void setGroupName(final String groupName) {
        this.groupName = groupName;
    }
}
